#####################################################################################
#	Author:			Bert Van Acker (bva.bmkr@gmail.com)
#	Version:		0.1.0
#	Lisence:		LGPL-3.0 (GNU Lesser General Public License version 3)
#
#	Description:	Communicator constants corresponding to the communcation protocol
#####################################################################################

# Bus communication
SJ_DefaultBaud = 115200
SJ_DefaultPortIn = 5000

# general
SJ_Timeout = 100        #in ms
SJ_CommandStart = "#"
SJ_CommandEnd = "\r"


#COMMAND constants
SJ_ActionLED = "LED"

# Navio2 constants
NAVIO_LED_Black = '0'
NAVIO_LED_Red = '1'
NAVIO_LED_Green = '2'
NAVIO_LED_Blue = '3'
NAVIO_LED_Yellow = '4'
NAVIO_LED_Cyan = '5'
NAVIO_LED_Magenta = '6'
NAVIO_LED_White = '7'


